@@ -16,7 +16,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
@@ -163,8 +163,10 @@ class DateParserCZ(DateParser):
         }
 
     quality_to_int = {
+        'přibližně'  : Date.QUAL_ESTIMATED,
         'odhadované' : Date.QUAL_ESTIMATED, 
         'odh.'       : Date.QUAL_ESTIMATED, 
+        'vypočteno'  : Date.QUAL_CALCULATED,
         'vypočtené'  : Date.QUAL_CALCULATED, 
         'vyp.'       : Date.QUAL_CALCULATED, 
         }
@@ -235,14 +237,14 @@ class DateDisplayCZ(DateDisplay):
             return date.get_text()
         elif start == Date.EMPTY:
             return ""
-        elif mod == Date.MOD_NONE:
-            date_decl_string = self.display_cal[cal](start)
-            date_decl_string = date_decl_string.replace("den ", "dna ")
-            date_decl_string = date_decl_string.replace("or ", "ora ")
-            date_decl_string = date_decl_string.replace("en ", "na ")
-            date_decl_string = date_decl_string.replace("ad ", "adu ")
-            date_decl_string = date_decl_string.replace("ec ", "ce ")
-            return date_decl_string
+#        elif mod == Date.MOD_NONE:
+#            date_decl_string = self.display_cal[cal](start)
+#            date_decl_string = date_decl_string.replace("den ", "dna ")
+#            date_decl_string = date_decl_string.replace("or ", "ora ")
+#            date_decl_string = date_decl_string.replace("en ", "na ")
+#            date_decl_string = date_decl_string.replace("ad ", "adu ")
+#            date_decl_string = date_decl_string.replace("ec ", "ce ")
+#            return date_decl_string
         elif mod == Date.MOD_SPAN:
             dat1 = self.display_cal[cal](start)
             dat2 = self.display_cal[cal](date.get_stop_date())
