@@ -1014,6 +1014,18 @@ class DbBsddbRead(DbReadBase, Callback):
         """
         return self.get_number_of_records(self.tag_map)
 
+    def is_empty(self):
+        """
+        Return true if there are no [primary] records in the database
+        """
+        for obj_map in [self.person_map, self.family_map, self.event_map,
+                        self.place_map, self.source_map, self.citation_map,
+                        self.media_map, self.repository_map, self.note_map,
+                        self.tag_map]:
+            if self.get_number_of_records(obj_map) > 0:
+                return False
+            return True
+
     def all_handles(self, table):
         """ return all the keys of a database table
 
@@ -1654,10 +1666,6 @@ class DbBsddbRead(DbReadBase, Callback):
             handle = handle.encode('utf-8')
         try:
             return table.get(handle, txn=self.txn)
-        except UnicodeDecodeError:
-            #we need to assume we opened data in python3 saved in python2
-            raw = table.db.get(handle, txn=self.txn)
-            return pickle.loads(raw, encoding='utf-8')
         except DBERRS as msg:
             self.__log_error()
             raise DbError(msg)
