@@ -66,6 +66,27 @@ from gramps.gui.dialog import (InfoDialog)
 
 LOG = logging.getLogger(".upgrade")
 
+def gramps_upgrade_pickle(self):
+    """
+    Upgrade to python3 pickle protocol.
+    """
+    import pickle
+    tables = (self.person_map, self.event_map, self.family_map, self.place_map,
+              self.repository_map, self.source_map, self.citation_map,
+              self.media_map, self.note_map, self.tag_map, self.metadata,
+              self.reference_map)
+    self.set_total(sum(map(len, tables)))
+    for data_map in tables:
+        for handle in data_map.keys():
+            raw = data_map.db.get(handle)
+            data = pickle.loads(raw, encoding='utf-8')
+            with BSDDBTxn(self.env, data_map) as txn:
+                txn.put(handle, data)
+            self.update()
+
+    with BSDDBTxn(self.env, self.metadata) as txn:
+        txn.put(b'upgraded', 'Yes')
+
 def gramps_upgrade_17(self):
     """
     Upgrade database from version 16 to 17. 
@@ -252,7 +273,10 @@ def gramps_upgrade_17(self):
     # Modify Media
     # ---------------------------------
     # Add new checksum field.
-    base_path = self.metadata.get(b'mediapath', '')
+    base_path = self.metadata.get(b'mediapath')
+    if base_path is None:
+        # Check that the mediapath is not set to None (bug #7844).
+        base_path = ''
     for handle in self.media_map.keys():
         media = self.media_map[handle]
         new_media = list(media)
@@ -656,7 +680,9 @@ def gramps_upgrade_16(self):
                       private)
         LOG.debug("      upgrade new_source %s" % [new_source])
         with BSDDBTxn(self.env, self.source_map) as txn:
-            txn.put(str(handle), new_source)
+            if isinstance(handle, UNITYPE):
+                handle = handle.encode('utf-8')
+            txn.put(handle, new_source)
         self.update()
 
     LOG.debug("%d sources upgraded with %d citations in %d seconds" % 
@@ -859,12 +885,12 @@ def convert_source_list_to_citation_list_16(self, source_list):
         new_citation = (new_handle, new_gramps_id,
                         date, page, confidence, ref, note_list, new_media_list,
                         new_data_map, new_change, private)
+        citation_list.append((new_handle))
         with BSDDBTxn(self.env, self.citation_map) as txn:
             if isinstance(new_handle, UNITYPE):
                 new_handle = new_handle.encode('utf-8')
             txn.put(new_handle, new_citation)
         self.cmap_index += 1
-        citation_list.append((new_handle))
     return citation_list
 
 def gramps_upgrade_15(self):
