@@ -17,24 +17,23 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-# $Id$
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
-Provide a simplified database access interface to the GRAMPS database.
+Provide a simplified database access interface to the Gramps database.
 """
 from __future__ import with_statement, unicode_literals
 
 from ..lib import (Person, Family, Event, Source, Place, Citation, 
-                   MediaObject, Repository, Note, Date)
+                   MediaObject, Repository, Note, Date, Tag)
+from ..lib.handle import Handle
 from ..datehandler import displayer
 from ..utils.string import gender as gender_map
 from ..utils.db import get_birth_or_fallback, get_death_or_fallback
-from ..plug.report.utils import place_name
 
 from ..display.name import displayer as name_displayer
+from ..display.place import displayer as place_displayer
 from ..lib import EventType
 from ..config import config
 from ..const import GRAMPS_LOCALE as glocale
@@ -48,15 +47,14 @@ from ..constfunc import STRTYPE
 #-------------------------------------------------------------------------
 class SimpleAccess(object):
     """
-    Provide a simplified database access system. This system has been designed to
-    ease the development of reports. 
+    Provide a simplified database access system. This system has been designed
+    to ease the development of reports.
     
     The user needs to take care when using this interface. Since it returns real 
     objects instead of database references, it can consume a significant amount
     of memory if the user is not careful.
     
-    Example
-    =======
+    **Example**
     
     A typical system of usage would be::
     
@@ -113,8 +111,8 @@ class SimpleAccess(object):
         """
         Initialize the SimpleAccess object with the database that will be used.
         
-        @param dbase: GRAMPS database object
-        @type dbase: DbBase
+        :param dbase: Gramps database object
+        :type dbase: DbBase
         """
         self.dbase = dbase
 
@@ -122,10 +120,10 @@ class SimpleAccess(object):
         """
         Return the name of the person, or and empty string if the person is None
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns the name of the person based of the program preferences
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns the name of the person based of the program preferences
+        :rtype: unicode
         """
         if isinstance(person, STRTYPE):
             person = self.dbase.get_person_from_handle(person)
@@ -139,10 +137,10 @@ class SimpleAccess(object):
         """
         Return the name of the person, or and empty string if the person is None
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns the name of the person based of the program preferences
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns the name of the person based of the program preferences
+        :rtype: unicode
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -155,12 +153,14 @@ class SimpleAccess(object):
         
     def first_name(self, person):
         """
-        Return the first name of the person, or and empty string if the person is None
+        Return the first name of the person, or and empty string if the person
+        is None
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns the first name of the person based of the program preferences
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns the first name of the person based of the program
+                 preferences
+        :rtype: unicode
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -172,12 +172,12 @@ class SimpleAccess(object):
 
     def gid(self, obj):
         """
-        Return the GRAMPS ID of the person or family
+        Return the Gramps ID of the person or family
 
-        @param obj: Person or Family object
-        @type obj: L{gen.lib.Person} or L{gen.lib.Family}
-        @return: Returns the GRAMPS Id value of the person or family
-        @rtype: unicode
+        :param obj: Person or Family object
+        :type obj: :py:class:`.Person` or :py:class:`.Family`
+        :return: Returns the Gramps ID value of the person or family
+        :rtype: unicode
         """
         if obj:
             return obj.get_gramps_id()
@@ -188,10 +188,10 @@ class SimpleAccess(object):
         """
         Return a string representing the gender of the person
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns a string indentifying the person's gender
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns a string indentifying the person's gender
+        :rtype: unicode
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -204,12 +204,12 @@ class SimpleAccess(object):
         """
         Return a person associated as a parent of the person
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @param func: function used to extract the appropriate parent
-        @type func: function
-        @return: mother or father of the associated person
-        @rtype: L{gen.lib.Person}
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :param func: function used to extract the appropriate parent
+        :type func: function
+        :return: mother or father of the associated person
+        :rtype: :py:class:`.Person`
         """
         assert(person is None or isinstance(person, Person))
 
@@ -225,12 +225,12 @@ class SimpleAccess(object):
         """
         Return a person associated as a parent of the family
 
-        @param family: Family object
-        @type family: L{gen.lib.Family}
-        @param func: function used to extract the appropriate parent
-        @type func: function
-        @return: mother or father of the associated family
-        @rtype: L{gen.lib.Family}
+        :param family: Family object
+        :type family: :py:class:`.Family`
+        :param func: function used to extract the appropriate parent
+        :type func: function
+        :return: mother or father of the associated family
+        :rtype: :py:class:`.Family`
         """
         assert(family is None or isinstance(family, Family))
 
@@ -244,12 +244,12 @@ class SimpleAccess(object):
         """
         Return a string describing the date associated with the person
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @param func: function used to extract the associated date information
-        @type func: function
-        @return: Returns a string describing the date
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :param func: function used to extract the associated date information
+        :type func: function
+        :return: Returns a string describing the date
+        :rtype: unicode
         """
         assert(person is None or isinstance(person, Person))
 
@@ -268,12 +268,12 @@ class SimpleAccess(object):
         """
         Return the date associated with the person
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @param func: function used to extract the associated date information
-        @type func: function
-        @return: Returns the date
-        @rtype: l{gen.lib.Date}
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :param func: function used to extract the associated date information
+        :type func: function
+        :return: Returns the date
+        :rtype: l{gen.lib.Date}
         """
         assert(person is None or isinstance(person, Person))
 
@@ -294,12 +294,12 @@ class SimpleAccess(object):
         """
         Return a string describing the place associated with the person
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @param func: function used to extract the associated place information
-        @type func: function
-        @return: Returns a string describing the place
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :param func: function used to extract the associated place information
+        :type func: function
+        :return: Returns a string describing the place
+        :rtype: unicode
         """
         assert(person is None or isinstance(person, Person))
 
@@ -309,18 +309,17 @@ class SimpleAccess(object):
                 event_handle = ref.get_reference_handle()
                 if event_handle:
                     event = self.dbase.get_event_from_handle(event_handle)
-                    place_handle = event.get_place_handle()
-                    return place_name(self.dbase, place_handle)
+                    return place_displayer.display_event(self.dbase, event)
         return ''
 
     def spouse(self, person):
         """
         Return the primary spouse of the person
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: The spouse identified as the person's primary spouse
-        @rtype: L{gen.lib.Person}
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: The spouse identified as the person's primary spouse
+        :rtype: :py:class:`.Person`
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -344,11 +343,11 @@ class SimpleAccess(object):
         Return a string describing the relationship between the person and
         his/per primary spouse.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns a string describing the relationship between the person and
-        his/per primary spouse.
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns a string describing the relationship between the
+                 person and his/per primary spouse.
+        :rtype: unicode
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -368,11 +367,11 @@ class SimpleAccess(object):
         Return a string describing the place where the person and his/her spouse
         where married.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns a string describing the place where the person and his/her spouse
-        where married.
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns a string describing the place where the person and
+                 his/her spouse where married.
+        :rtype: unicode
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -391,8 +390,7 @@ class SimpleAccess(object):
                         events = [ evnt for evnt in elist 
                                    if event.type == EventType.MARRIAGE ]
                         if events:
-                            place_handle = events[0].get_place_handle()
-                            return place_name(self.dbase, place_handle)
+                            return place_displayer.display_event(self.dbase, events[0])
         return ''
 
     def marriage_date(self, person):
@@ -400,11 +398,11 @@ class SimpleAccess(object):
         Return a string indicating the date when the person and his/her spouse
         where married.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns a string indicicating the date when the person and his/her spouse
-        where married.
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns a string indicicating the date when the person and
+                 his/her spouse where married.
+        :rtype: unicode
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -432,10 +430,11 @@ class SimpleAccess(object):
         """
         Return a list of the children as the children of the primary spouse.
 
-        @param obj: Person or Family object
-        @type obj: L{gen.lib.Person} or L{gen.lib.Family}
-        @return: Returns a list of L{gen.lib.Person} objects representing the children
-        @rtype: list
+        :param obj: Person or Family object
+        :type obj: :py:class:`.Person` or :py:class:`.Family`
+        :return: Returns a list of :py:class:`.Person` objects representing the
+                 children
+        :rtype: list
         """
         assert(obj is None or isinstance(obj, (Person, Family)))
 
@@ -457,11 +456,11 @@ class SimpleAccess(object):
         Return the primary father of the person or the father of the associated
         family.
 
-        @param obj: Person or Family object
-        @type obj: L{gen.lib.Person} or L{gen.lib.Family}
-        @return: The father in the person's primary family or the father of the
+        :param obj: Person or Family object
+        :type obj: :py:class:`.Person` or :py:class:`.Family`
+        :return: The father in the person's primary family or the father of the
                  family
-        @rtype: L{gen.lib.Person}
+        :rtype: :py:class:`.Person`
         """
         if isinstance(obj, Person):
             return self.__parent(obj, Family.get_father_handle)
@@ -475,11 +474,11 @@ class SimpleAccess(object):
         Returns the primary mother of the person or the mother of the associated
         family.
 
-        @param obj: Person object
-        @type obj: L{gen.lib.Person} or L{gen.lib.Family}
-        @return: The mother in the person's primary family or the mother of the
+        :param obj: Person object
+        :type obj: :py:class:`.Person` or :py:class:`.Family`
+        :return: The mother in the person's primary family or the mother of the
                  family
-        @rtype: L{gen.lib.Person}
+        :rtype: :py:class:`.Person`
         """
         if isinstance(obj, Person):
             return self.__parent(obj, Family.get_mother_handle)
@@ -492,10 +491,10 @@ class SimpleAccess(object):
         """
         Return a string indicating the date when the person's birth.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns a string indicating the date when the person's birth.
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns a string indicating the date when the person's birth.
+        :rtype: unicode
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -505,10 +504,10 @@ class SimpleAccess(object):
         """
         Return the date when the person's birth.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns the date when the person's birth.
-        @rtype: L{gen.lib.Date}
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns the date when the person's birth.
+        :rtype: :py:class:`.Date`
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -519,10 +518,10 @@ class SimpleAccess(object):
         """
         Return the date of the person's birth or fallback event.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns the date when the person's birth or fallback.
-        @rtype: L{gen.lib.Date}
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns the date when the person's birth or fallback.
+        :rtype: :py:class:`.Date`
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -538,10 +537,10 @@ class SimpleAccess(object):
         """
         Return a string indicating the place of the person's birth.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns a string indicating the place of the person's birth.
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns a string indicating the place of the person's birth.
+        :rtype: unicode
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -551,10 +550,10 @@ class SimpleAccess(object):
         """
         Return a string indicating the date when the person's death.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns a string indicating the date when the person's death.
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns a string indicating the date when the person's death.
+        :rtype: unicode
         """
         if isinstance(person, STRTYPE):
             person = self.dbase.get_person_from_handle(person)
@@ -564,10 +563,10 @@ class SimpleAccess(object):
         """
         Return the date when the person's death.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns the date when the person's death.
-        @rtype: L{gen.lib.Date}
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns the date when the person's death.
+        :rtype: :py:class:`.Date`
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -577,10 +576,10 @@ class SimpleAccess(object):
         """
         Return the date of the person's death or fallback event.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns the date of the person's death or fallback.
-        @rtype: L{gen.lib.Date}
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns the date of the person's death or fallback.
+        :rtype: :py:class:`.Date`
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -596,10 +595,10 @@ class SimpleAccess(object):
         """
         Return a string indicating the place of the person's death.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: Returns a string indicating the place of the person's death.
-        @rtype: unicode
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: Returns a string indicating the place of the person's death.
+        :rtype: unicode
         """
         if isinstance(person, STRTYPE): 
             person = self.dbase.get_person_from_handle(person)
@@ -609,16 +608,15 @@ class SimpleAccess(object):
         """
         Return a string indicating the place of the event
 
-        @param event: Event object
-        @type event: L{gen.lib.Event}
-        @return: Returns a string indicating the place of the event
-        @rtype: unicode
+        :param event: Event object
+        :type event: :py:class:`.Event`
+        :return: Returns a string indicating the place of the event
+        :rtype: unicode
         """
         assert(event is None or isinstance(event, Event))
 
         if event:
-            place_handle = event.get_place_handle()
-            return place_name(self.dbase, place_handle)
+            return place_displayer.display_event(self.dbase, event)
         else:
             return ''
 
@@ -626,10 +624,10 @@ class SimpleAccess(object):
         """
         Return a string representation a date_obj
 
-        @param date_obj: Date object
-        @type date_obj: L{gen.lib.Date}
-        @return: Returns a string representation a date_obj
-        @rtype: unicode
+        :param date_obj: Date object
+        :type date_obj: :py:class:`.Date`
+        :return: Returns a string representation a date_obj
+        :rtype: unicode
         """
         if date_obj:
             return displayer.display(date_obj)
@@ -640,10 +638,10 @@ class SimpleAccess(object):
         """
         Return a string indicating the date of the event
 
-        @param event: Event object
-        @type event: L{gen.lib.Event}
-        @return: Returns a string indicating the date of the event
-        @rtype: unicode
+        :param event: Event object
+        :type event: :py:class:`.Event`
+        :return: Returns a string indicating the date of the event
+        :rtype: unicode
         """
         assert(event is None or isinstance(event, Event))
         date_obj = event.get_date_object()
@@ -656,10 +654,10 @@ class SimpleAccess(object):
         """
         Return a string indicating the date of the event
 
-        @param event: Event object
-        @type event: L{gen.lib.Event}
-        @return: Returns a string indicating the date of the event
-        @rtype: unicode
+        :param event: Event object
+        :type event: :py:class:`.Event`
+        :return: Returns a string indicating the date of the event
+        :rtype: unicode
         """
         assert(event is None or isinstance(event, Event))
         if event:
@@ -669,10 +667,10 @@ class SimpleAccess(object):
         """
         Return a string indicating the type of the event
 
-        @param event: Event object
-        @type event: L{gen.lib.Event}
-        @return: Returns a string indicating the type of the event
-        @rtype: unicode
+        :param event: Event object
+        :type event: :py:class:`.Event`
+        :return: Returns a string indicating the type of the event
+        :rtype: unicode
         """
         assert(event is None or isinstance(event, Event))
         if event:
@@ -683,15 +681,15 @@ class SimpleAccess(object):
     def events(self, obj, restrict=None):
         """
         Return a list of events associated with the object. This object
-        can be either a L{gen.lib.Person} or L{gen.lib.Family}.
+        can be either a :py:class:`.Person` or :py:class:`.Family`.
 
-        @param obj: Person or Family
-        @type obj: L{gen.lib.Person} or L{gen.lib.Family}
-        @param restrict: Optional list of strings that will limit the types
-        of events to those of the specified types.
-        @type restrict: list
-        @return: list of events associated with the object
-        @rtype: list
+        :param obj: Person or Family
+        :type obj: :py:class:`.Person` or :py:class:`.Family`
+        :param restrict: Optional list of strings that will limit the types
+                         of events to those of the specified types.
+        :type restrict: list
+        :return: list of events associated with the object
+        :rtype: list
         """
         assert(obj is None or isinstance(obj, (Person, Family)))
         assert(isinstance(restrict, list) or restrict is None)
@@ -711,12 +709,12 @@ class SimpleAccess(object):
     def sources(self, obj):
         """
         Return a list of events associated with the object. This object
-        can be either a L{gen.lib.Person} or L{gen.lib.Family}.
+        can be either a :py:class:`.Person` or :py:class:`.Family`.
 
-        @param obj: Person or Family
-        @type obj: L{gen.lib.Person} or L{gen.lib.Family}
-        @return: list of events associated with the object
-        @rtype: list
+        :param obj: Person or Family
+        :type obj: :py:class:`.Person` or :py:class:`.Family`
+        :return: list of events associated with the object
+        :rtype: list
         """
         assert(obj is None or isinstance(obj, (Person, Family, Event)))
 
@@ -730,11 +728,11 @@ class SimpleAccess(object):
         """
         Return a list of families in which the person is listed as a parent.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: list of L{gen.lib.Family} objects in which the person is listed
-           as a parent.
-        @rtype: list
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: list of :py:class:`.Family` objects in which the person is
+                 listed as a parent.
+        :rtype: list
         """
         if isinstance(person, STRTYPE):
             person = self.dbase.get_person_from_handle(person)
@@ -749,11 +747,11 @@ class SimpleAccess(object):
         """
         Return a list of families in which the person is listed as a child.
 
-        @param person: Person object
-        @type person: L{gen.lib.Person}
-        @return: list of L{gen.lib.Family} objects in which the person is listed
-           as a child.
-        @rtype: list
+        :param person: Person object
+        :type person: :py:class:`.Person`
+        :return: list of :py:class:`.Family` objects in which the person is
+                 listed as a child.
+        :rtype: list
         """
         if isinstance(person, STRTYPE):
             person = self.dbase.get_person_from_handle(person)
@@ -769,8 +767,8 @@ class SimpleAccess(object):
         Return a all the objects of a particular type in the database, one 
         at a time as an iterator. The user can treat this just like a list. 
 
-        @return: list of objects of a particular type in the database
-        @rtype: list
+        :return: list of objects of a particular type in the database
+        :rtype: list
         """
         
         with gen_cursor() as cursor:
@@ -785,8 +783,8 @@ class SimpleAccess(object):
            for person in sa.all_people():
               sa.print(person)
 
-        @return: list of people in the database
-        @rtype: list
+        :return: list of people in the database
+        :rtype: list
         """
         
         with self.dbase.get_person_cursor() as cursor:
@@ -804,8 +802,8 @@ class SimpleAccess(object):
            for person in sa.all_families():
               sa.print(sa.father(person))
 
-        @return: list of families in the database
-        @rtype: list
+        :return: list of families in the database
+        :rtype: list
         """
         return self.__all_objects(self.dbase.get_family_cursor, 
                                   self.dbase.get_family_from_handle)
@@ -818,8 +816,8 @@ class SimpleAccess(object):
            for person in sa.all_events():
               sa.print(sa.event_place(event))
 
-        @return: list of events in the database
-        @rtype: list
+        :return: list of events in the database
+        :rtype: list
         """
         return self.__all_objects(self.dbase.get_event_cursor, 
                                   self.dbase.get_event_from_handle)
@@ -829,20 +827,86 @@ class SimpleAccess(object):
         Return all the sources in the database, one at a time as an iterator.
         The user can treat this just like a list. For example::
 
-        @return: list of sources in the database
-        @rtype: list
+        :return: list of sources in the database
+        :rtype: list
         """
         return self.__all_objects(self.dbase.get_source_cursor, 
                                   self.dbase.get_source_from_handle)
 
+    def all_citations(self):
+        """
+        Return all the citations in the database, one at a time as an iterator.
+        The user can treat this just like a list. For example::
+
+        :return: list of citations in the database
+        :rtype: list
+        """
+        return self.__all_objects(self.dbase.get_citation_cursor, 
+                                  self.dbase.get_citation_from_handle)
+
+    def all_repositories(self):
+        """
+        Return all the repositories in the database, one at a time as an iterator.
+        The user can treat this just like a list. For example::
+
+        :return: list of repositories in the database
+        :rtype: list
+        """
+        return self.__all_objects(self.dbase.get_repsoitory_cursor, 
+                                  self.dbase.get_repository_from_handle)
+
+    def all_media(self):
+        """
+        Return all the media in the database, one at a time as an iterator.
+        The user can treat this just like a list. For example::
+
+        :return: list of media in the database
+        :rtype: list
+        """
+        return self.__all_objects(self.dbase.get_media_cursor, 
+                                  self.dbase.get_object_from_handle)
+
+    def all_places(self):
+        """
+        Return all the places in the database, one at a time as an iterator.
+        The user can treat this just like a list. For example::
+
+        :return: list of places in the database
+        :rtype: list
+        """
+        return self.__all_objects(self.dbase.get_place_cursor, 
+                                  self.dbase.get_place_from_handle)
+
+    def all_notes(self):
+        """
+        Return all the notes in the database, one at a time as an iterator.
+        The user can treat this just like a list. For example::
+
+        :return: list of notes in the database
+        :rtype: list
+        """
+        return self.__all_objects(self.dbase.get_note_cursor, 
+                                  self.dbase.get_note_from_handle)
+
+    def all_tags(self):
+        """
+        Return all the tags in the database, one at a time as an iterator.
+        The user can treat this just like a list. For example::
+
+        :return: list of tags in the database
+        :rtype: list
+        """
+        return self.__all_objects(self.dbase.get_tag_cursor, 
+                                  self.dbase.get_tag_from_handle)
+
     def title(self, source):
         """
         Return the title of the source.
 
-        @param source: Source object
-        @type source: L{gen.lib.Source}
-        @return: title of the source
-        @rtype: unicode
+        :param source: Source object
+        :type source: :py:class:`.Source`
+        :return: title of the source
+        :rtype: unicode
         """
         assert(source is None or isinstance(source, Source))
         if source:
@@ -853,10 +917,10 @@ class SimpleAccess(object):
         """
         Return the page of the citation.
 
-        @param citation: Source object
-        @type citation: L{gen.lib.Citation}
-        @return: title of the citation
-        @rtype: unicode
+        :param citation: Source object
+        :type citation: :py:class:`Citation <.lib.citation.Citation>`
+        :return: title of the citation
+        :rtype: unicode
         """
         assert(citation is None or isinstance(citation, Citation))
         if citation:
@@ -867,10 +931,10 @@ class SimpleAccess(object):
         """
         Return the author of the source.
 
-        @param source: Source object
-        @type source: L{gen.lib.Source}
-        @return: author of the source
-        @rtype: unicode
+        :param source: Source object
+        :type source: :py:class:`.Source`
+        :return: author of the source
+        :rtype: unicode
         """
         assert(source is None or isinstance(source, Source))
         if source:
@@ -893,9 +957,10 @@ class SimpleAccess(object):
         """
         Given a object_class, prop, and value return a display string
         describing object.  
-        object_class is "Person", "Source", etc.
-        prop is "gramps_id", or "handle"
-        value is a gramps_id or handle.
+
+        :param object_class: "Person", "Source", etc.
+        :param prop: "gramps_id", or "handle"
+        :param value: gramps_id or handle.
         """
         if object_class in self.dbase.get_table_names():
             obj = self.dbase.get_table_metadata(object_class)\
@@ -926,9 +991,9 @@ class SimpleAccess(object):
                     return "%s: [%s]" % (_(object_class), 
                                             self.gid(obj))
                 elif isinstance(obj, Place):
+                    place_title = place_displayer.display(self.dbase, obj)
                     return "%s: %s [%s]" % (_(object_class), 
-                                            place_name(self.dbase, 
-                                                       obj.handle), 
+                                            place_title,
                                             self.gid(obj))
                 elif isinstance(obj, Repository):
                     return "%s: %s [%s]" % (_(object_class), 
@@ -938,56 +1003,67 @@ class SimpleAccess(object):
                     return "%s: %s [%s]" % (_(object_class), 
                                             obj.type, 
                                             self.gid(obj))
+                elif isinstance(obj, Tag):
+                    return "%s: [%s]" % (_(object_class), 
+                                         obj.name)
                 else:
-                    return "Error: incorrect object class: '%s'" % type(obj)
+                    return "Error: incorrect object class in display: '%s'" % type(obj)
             else:
                 return "Error: missing object"
+        elif object_class == "Handle":
+            return "%s.handle [%s]" % (prop, value)
         else:
-            return "Error: invalid object class: '%s'" % object_class
+            return "Error: invalid object class in display: '%s'" % object_class
 
-    def describe(self, obj):
+    def describe(self, obj, prop=None, value=None):
         """
         Given a object, return a string describing the object.  
         """
+        if prop and value:
+            if self.dbase.get_table_metadata(obj):
+                obj = self.dbase.get_table_metadata(obj)[prop + "_func"](value)
         if isinstance(obj, Person):
-            return self.name(obj)
+            return "%s [%s]" % (self.name(obj), 
+                                self.gid(obj))
         elif isinstance(obj, Event):
-            return self.event_type(obj)
+            return "%s [%s]" % (self.event_type(obj),
+                                self.gid(obj))
         elif isinstance(obj, Family):
-            father = self.father(obj)
-            mother = self.mother(obj)
-            if father:
-                father_text = self.name(father)
-            else:
-                father_text = _("Unknown father")
-            if mother:
-                mother_text = self.name(mother)
-            else:
-                mother_text = _("Unknown mother")
-            return "%s and %s" % (mother_text, father_text)
+            return "%s/%s [%s]" % (self.name(self.mother(obj)), 
+                                   self.name(self.father(obj)), 
+                                   self.gid(obj))
         elif isinstance(obj, MediaObject):
-            return obj.desc
-        elif isinstance(obj, Citation):
-            return obj.gramps_id
+            return "%s [%s]" % (obj.desc, 
+                                self.gid(obj))
         elif isinstance(obj, Source):
-            return self.title(obj)
+            return "%s [%s]" % (self.title(obj), 
+                                self.gid(obj))
+        elif isinstance(obj, Citation):
+            return "[%s]" % (self.gid(obj))
         elif isinstance(obj, Place):
-            return place_name(self.dbase, obj.handle)
+            place_title = place_displayer.display(self.dbase, obj)
+            return "%s [%s]" % (place_title,
+                                self.gid(obj))
         elif isinstance(obj, Repository):
-            return obj.gramps_id
+            return "%s [%s]" % (obj.type, 
+                                self.gid(obj))
         elif isinstance(obj, Note):
-            return obj.gramps_id
-        elif obj is None:
-            return ""
+            return "%s [%s]" % (obj.type, 
+                                self.gid(obj))
+        elif isinstance(obj, Tag):
+            return "[%s]" % (obj.name)
+        elif isinstance(obj, Handle):
+            return "%s.handle [%s]" % (prop, obj.handle)
         else:
-            return "Error: incorrect object class: '%s'" % type(obj)
+            return "Error: incorrect object class in describe: '%s'" % type(obj)
 
     def get_link(self, object_class, prop, value):
         """
         Given a object_class, prop, and value return the object.
-        object_class is "Person", "Source", etc.
-        prop is "gramps_id", or "handle"
-        value is a gramps_id or handle.
+
+        :param object_class: "Person", "Source", etc.
+        :param prop: "gramps_id", or "handle"
+        :param value: gramps_id or handle.
         """
         if object_class in self.dbase.get_table_names():
             return self.dbase.get_table_metadata(object_class) \
@@ -995,16 +1071,15 @@ class SimpleAccess(object):
 
 def by_date(event1, event2):
     """
-    DEPRECATED! 
     Sort function that will compare two events by their dates.
 
-    @param event1: first event
-    @type event1: L{Event}
-    @param event2: second event
-    @type event2: L{Event}
-    @return: Returns -1 if event1 < event2, 0 if they are equal, and
+    :param event1: first event
+    :type event1: :py:class:`.Event`
+    :param event2: second event
+    :type event2: :py:class:`.Event`
+    :return: Returns -1 if event1 < event2, 0 if they are equal, and
        1 if they are the same.
-    @rtype: int
+    :rtype: int
     """
     if event1 and event2:
         return cmp(event1.get_date_object() , event2.get_date_object())
