@@ -17,11 +17,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# $Id$
-
 """
 File and folder related utility functions
 """
@@ -34,6 +32,8 @@ File and folder related utility functions
 import os
 import sys
 import shutil
+import io
+import hashlib
 import logging
 LOG = logging.getLogger(".gen.utils.file")
 
@@ -184,3 +184,15 @@ def search_for(name):
             if os.access(fname, os.X_OK) and not os.path.isdir(fname):
                 return 1
     return 0
+
+def create_checksum(full_path):
+    """
+    Create a md5 hash for the given file.
+    """
+    full_path = os.path.normpath(full_path)
+    try:
+        with io.open(full_path, 'rb') as media_file:
+            md5sum = hashlib.md5(media_file.read()).hexdigest()
+    except IOError:
+            md5sum = ''
+    return md5sum
