@@ -85,6 +85,7 @@ _LOCALE_NAMES = {
     'he': ('Hebrew_Israel', '1255', _("Hebrew")),
     'hr': ('Croatian_Croatia', '1250', _("Croatian")),
     'hu': ('Hungarian_Hungary', '1250', _("Hungarian")),
+    'is': ('Icelandic', '1252', _("Icelandic")),
     'it': ('Italian_Italy', '1252', _("Italian")),
     'ja': ('Japanese_Japan', '932', _("Japanese")),
     'lt': ('Lithuanian_Lithuania', '1252', _("Lithuanian")),
@@ -100,7 +101,7 @@ _LOCALE_NAMES = {
     'sk': ('Slovak_Slovakia', '1250', _("Slovak"),),
     'sl': ('Slovenian_Slovenia', '1250', _("Slovenian")),
     'sq': ('Albanian_Albania', '1250', _("Albanian")),
-    'sr': ('Serbian(Cyrillic)_Serbia and Montenegro', '1251', None), #Gramps's Serbian translation is not yet ready
+    'sr': ('Serbian (Cyrillic)_Serbia', '1251', _("Serbian")),
     'sv': ('Swedish_Sweden', '1252', _("Swedish")),
     'tr': ('Turkish_Turkey', '1254', _("Turkish")),
     'uk': ('Ukrainian_Ukraine', '1251', _("Ukrainian")),
@@ -481,7 +482,7 @@ class GrampsLocale(object):
             if not sys.platform == 'win32':
                 locale.bindtextdomain(self.localedomain, self.localedir)
             else:
-                self._win_bindtextdomain(self.localedomain,
+                self._win_bindtextdomain(self.localedomain.encode('utf-8'),
                                          self.localedir.encode('utf-8'))
 
     def _init_secondary_locale(self):
