@@ -998,6 +998,20 @@ class GrampsPreferences(ConfigureDialog):
         table.attach(obox, 1, 3, row, row+1, yoptions=0)
         row += 1
         
+        # Place format:
+        obox = Gtk.ComboBoxText()
+        formats = [_('Title'), _('Automatic')]
+        list(map(obox.append_text, formats))
+        active = config.get('preferences.place-format')
+        if active >= len(formats):
+            active = 0
+        obox.set_active(active)
+        obox.connect('changed', self.place_format_changed)
+        lwidget = BasicLabel("%s: " % _('Place format'))
+        table.attach(lwidget, 0, 1, row, row+1, yoptions=0)
+        table.attach(obox, 1, 3, row, row+1, yoptions=0)
+        row += 1
+        
         # Age precision:
         # precision=1 for "year", 2: "year, month" or 3: "year, month, days"
         obox = Gtk.ComboBoxText()
@@ -1158,6 +1172,12 @@ class GrampsPreferences(ConfigureDialog):
                  _('Changing the date format will not take '
                    'effect until the next time Gramps is started.'))
 
+    def place_format_changed(self, obj):
+        config.set('preferences.place-format', obj.get_active())
+        OkDialog(_('Change is not immediate'), 
+                 _('Changing the place format will not take '
+                   'effect until the next time Gramps is started.'))
+
     def date_calendar_changed(self, obj): 
         config.set('preferences.calendar-format-report', obj.get_active())
     
@@ -1324,10 +1344,7 @@ class GrampsPreferences(ConfigureDialog):
             return
 
         if len(addon_update_list) > 0:
-            try:
-                PluginWindows.UpdateAddons(self.uistate, [], addon_update_list)
-            except WindowActiveError:
-                pass
+            PluginWindows.UpdateAddons(addon_update_list, self.window)
         else:
             check_types = config.get('behavior.check-for-update-types')
             OkDialog(_("There are no available addons of this type"),
