@@ -16,7 +16,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
     
@@ -46,6 +46,7 @@ from .familyldsembedlist import FamilyLdsEmbedList
 from .gallerytab import GalleryTab
 from .ldsembedlist import LdsEmbedList
 from .locationembedlist import LocationEmbedList
+from .mediaattrembedlist import MediaAttrEmbedList
 from .mediabackreflist import MediaBackRefList
 from .nameembedlist import NameEmbedList
 from .notebackreflist import NoteBackRefList
