@@ -103,17 +103,19 @@ class CitationSidebarFilter(SidebarFilter):
         self.tag.pack_start(cell, True)
         self.tag.add_attribute(cell, 'text', 0)
 
-        self.add_text_entry(_('Source: ID'), self.filter_src_id)
-        self.add_text_entry(_('Source: Title'), self.filter_src_title)
-        self.add_text_entry(_('Source: Author'), self.filter_src_author)
-        self.add_text_entry(_('Source: Abbreviation'), self.filter_src_abbr)
-        self.add_text_entry(_('Source: Publication'), self.filter_src_pub)
-        self.add_text_entry(_('Source: Note'), self.filter_src_note)
-        self.add_text_entry(_('Citation: ID'), self.filter_id)
-        self.add_text_entry(_('Citation: Volume/Page'), self.filter_page)
-        self.add_text_entry(_('Citation: Date'), self.filter_date)
+        self.add_heading(_('Source:'))
+        self.add_text_entry(_('ID'), self.filter_src_id)
+        self.add_text_entry(_('Title'), self.filter_src_title)
+        self.add_text_entry(_('Author'), self.filter_src_author)
+        self.add_text_entry(_('Abbreviation'), self.filter_src_abbr)
+        self.add_text_entry(_('Publication'), self.filter_src_pub)
+        self.add_text_entry(_('Note'), self.filter_src_note)
+        self.add_heading(_('Citation:'))
+        self.add_text_entry(_('ID'), self.filter_id)
+        self.add_text_entry(_('Volume/Page'), self.filter_page)
+        self.add_text_entry(_('Date'), self.filter_date)
         self.add_entry(_('Citation: Minimum Confidence|Min. Conf.'), self.filter_conf)
-        self.add_text_entry(_('Citation: Note'), self.filter_note)
+        self.add_text_entry(_('Note'), self.filter_note)
         self.add_entry(_('Tag'), self.tag)
         self.add_filter_entry(_('Custom filter'), self.generic)
         self.add_entry(None, self.filter_regex)
