@@ -16,11 +16,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# $Id$
-
 "Handle bookmarks for the gramps interface."
 
 #-------------------------------------------------------------------------
@@ -96,7 +94,7 @@ class Bookmarks :
         self.bookmarks = None
         self.update_bookmarks()
         self.active = DISABLED
-        self.action_group = Gtk.ActionGroup('Bookmarks')
+        self.action_group = Gtk.ActionGroup(name='Bookmarks')
         self.connect_signals()
         self.dbstate.connect('database-changed', self.db_changed)
 
@@ -138,7 +136,7 @@ class Bookmarks :
         if self.active != DISABLED:
             self.uistate.uimanager.remove_ui(self.active)
             self.uistate.uimanager.remove_action_group(self.action_group)
-            self.action_group = Gtk.ActionGroup('Bookmarks')
+            self.action_group = Gtk.ActionGroup(name='Bookmarks')
             self.uistate.uimanager.ensure_update()
             self.active = DISABLED
 
