@@ -360,7 +360,8 @@ class GrampletBar(Gtk.Notebook):
         height = min(int(self.uistate.screen_height() * 0.20), 400)
         gramplet.set_size_request(width, height)
 
-        page_num = self.append_page(gramplet, Gtk.Label(label=''))
+        label = self.__create_tab_label(gramplet)
+        page_num = self.append_page(gramplet, label)
         return page_num
 
     def __create_tab_label(self, gramplet):
@@ -619,7 +620,7 @@ class DetachedWindow(ManagedWindow):
                         None,
                         self.title)
         self.window.move(x_pos, y_pos)
-        self.window.set_size_request(gramplet.detached_width,
+        self.window.set_default_size(gramplet.detached_width,
                                      gramplet.detached_height)
         self.window.add_button(Gtk.STOCK_HELP, Gtk.ResponseType.HELP)
         self.window.connect('response', self.handle_response)
