@@ -232,6 +232,7 @@ class GrampletWindow(ManagedWindow):
         """
         self.title = gramplet.title + " " + _("Gramplet")
         self.gramplet = gramplet
+        self.gramplet.scrolledwindow.set_vexpand(True)
         self.gramplet.detached_window = self
         # Keep track of what state it was in:
         self.docked_state = gramplet.gstate
@@ -295,6 +296,7 @@ class GrampletWindow(ManagedWindow):
         """
         Dock the detached GrampletWindow back in the column from where it came.
         """
+        self.gramplet.scrolledwindow.set_vexpand(False)
         self.gramplet.detached_window = None
         self.gramplet.pane.detached_gramplets.remove(self.gramplet)
         if self.docked_state == "minimized":
@@ -325,6 +327,14 @@ class GrampletWindow(ManagedWindow):
             expand, fill, padding, pack = column.query_child_packing(gramplet.mainframe)
             expand = gramplet.gstate == "maximized" and gramplet.expand
             column.set_child_packing(gramplet.mainframe, expand, fill, padding, pack)
+        # set_image on buttons as get_image is None in first run
+        # or point to invalid adress in every other run
+        self.gramplet.gvstate.set_image(self.gramplet.xml.get_object(
+                                        'gvstateimage'))
+        self.gramplet.gvclose.set_image(self.gramplet.xml.get_object(
+                                        'gvcloseimage'))
+        self.gramplet.gvproperties.set_image(self.gramplet.xml.get_object(
+                                             'gvpropertiesimage'))
         self.gramplet.gvclose.show()
         self.gramplet.gvstate.show()
         self.gramplet.gvproperties.show()
