@@ -18,7 +18,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #------------------------------------------------------------------------
@@ -275,6 +275,7 @@ register(GRAMPLET,
          gramplet_title=_("gramplet|To Do"),
          version="1.0.0",
          gramps_target_version="4.1",
+         navtypes=["Dashboard"],
          )
 
 register(GRAMPLET, 
@@ -1226,3 +1227,17 @@ register(GRAMPLET,
          gramplet = 'SoundGen',
          gramplet_title=_("SoundEx"),
          )
+
+register(GRAMPLET,
+         id="Place Locations",
+         name=_("Place Locations"),
+         description = _("Gramplet showing the locations of a place over time"),
+         version="1.0.0",
+         gramps_target_version="4.1",
+         status = STABLE,
+         fname="locations.py",
+         height=200,
+         gramplet = 'Locations',
+         gramplet_title=_("Locations"),
+         navtypes=["Place"],
+         )
