@@ -17,11 +17,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# $Id$
-
 #-------------------------------------------------------------------------
 #
 # Python modules
@@ -51,8 +49,9 @@ import cairo
 # Gramps Modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.lib import EventType, Place
+from gramps.gen.lib import EventType, Place, PlaceType, PlaceRef
 from gramps.gen.display.name import displayer as _nd
+from gramps.gen.display.place import displayer as _pd
 from gramps.gui.views.navigationview import NavigationView
 from gramps.gen.utils.libformatting import FormattingHelper
 from gramps.gen.errors import WindowActiveError
@@ -61,6 +60,7 @@ from gramps.gui.managedwindow import ManagedWindow
 from gramps.gen.config import config
 from gramps.gui.editors import EditPlace, EditEvent, EditFamily, EditPerson
 from gramps.gui.selectors.selectplace import SelectPlace
+from gramps.gen.constfunc import conv_to_unicode
 
 from gi.repository import OsmGpsMap as osmgpsmap
 from . import constants
@@ -124,6 +124,7 @@ class GeoGraphyView(OsmGps, NavigationView):
 
         ('geography.map_service', constants.OPENSTREETMAP),
         ('geography.max_places', 5000),
+        ('geography.use-keypad', True),
         )
 
     def __init__(self, title, pdata, dbstate, uistate,
@@ -199,6 +200,8 @@ class GeoGraphyView(OsmGps, NavigationView):
         NavigationView.change_page(self)
         self.uistate.clear_filter_results()
         self.end_selection = None
+        self.osm.grab_focus()
+        self.set_crosshair(config.get("geography.show_cross"))
 
     def do_size_request(self, requisition):
         """
@@ -241,6 +244,8 @@ class GeoGraphyView(OsmGps, NavigationView):
         if self.active:
             self.bookmarks.redraw()
         self.build_tree()
+        self.osm.grab_focus()
+        self.set_crosshair(config.get("geography.show_cross"))
 
     def can_configure(self):
         """
@@ -364,6 +369,16 @@ class GeoGraphyView(OsmGps, NavigationView):
             changemapitem.show()
             changemapitem.connect("activate", self.change_map, map)
             changemap.append(changemapitem)
+
+        clear_text = _("Clear the '%(map)s' tiles cache.") % {
+                   'map' : map_name
+                  }
+        self.clearmap = Gtk.MenuItem(label=clear_text)
+        clearmap = self.clearmap
+        clearmap.connect("activate", self.clear_map, constants.tiles_path[config.get("geography.map_service")])
+
+        clearmap.show()
+        menu.append(clearmap)
         menu.show()
         menu.popup(None, None,
                    lambda menu, data: (event.get_root_coords()[0],
@@ -371,6 +386,17 @@ class GeoGraphyView(OsmGps, NavigationView):
                    None, event.button, event.time)
         return 1
 
+
+    def clear_map(self, menu, the_map):
+        """
+        We need to clean the tiles cache for the current map
+        """
+        import shutil
+     
+        path = "%s%c%s" % ( config.get('geography.path'), os.sep, the_map )
+        shutil.rmtree(path)
+        pass
+
     def add_specific_menu(self, menu, event, lat, lon):
         """
         Add specific entry to the navigation menu.
@@ -764,8 +790,8 @@ class GeoGraphyView(OsmGps, NavigationView):
         Print or save the view that is currently shown
         """
         req = self.osm.get_allocation()
-        widthpx = req.width / 0.70
-        heightpx = req.height / 0.70
+        widthpx = req.width
+        heightpx = req.height
         prt = CairoPrintSave(widthpx, heightpx, self.osm.do_draw, self.osm)
         prt.run()
 
@@ -814,12 +840,14 @@ class GeoGraphyView(OsmGps, NavigationView):
         """
         self.mark = mark
         place = self.dbstate.db.get_place_from_gramps_id(self.mark[9])
-        loc = place.get_main_location()
+        parent_list = place.get_placeref_list()
+        if len(parent_list) > 0:
+            parent = parent_list[0].ref
+        else:
+            parent = None
         self.select_fct = PlaceSelection(self.uistate, self.dbstate, self.osm,
                        self.selection_layer, self.place_list,
-                       lat, lon, self.__edit_place,
-                       (loc.get_country(), loc.get_state(), loc.get_county())
-                      )
+                       lat, lon, self.__edit_place, parent)
 
     def edit_person(self, menu, event, lat, lon, mark):
         """
@@ -876,15 +904,19 @@ class GeoGraphyView(OsmGps, NavigationView):
         selector = SelectPlace(self.dbstate, self.uistate, [])
         place = selector.run()
         if place:
-            loc = place.get_main_location()
-            oldv = (loc.get_country(), loc.get_state(),
-                    loc.get_county()) if loc else None
+            parent_list = place.get_placeref_list()
+            if len(parent_list) > 0:
+                parent = parent_list[0].ref
+            else:
+                parent = None
             places_handle = self.dbstate.db.iter_place_handles()
             nb_places = 0
             gids = ""
+            place_title = _pd.display(self.dbstate.db, place)
             for place_hdl in places_handle:
                 plce = self.dbstate.db.get_place_from_handle(place_hdl)
-                if plce.get_title() == place.get_title():
+                plce_title = _pd.display(self.dbstate.db, plce)
+                if plce_title == place_title:
                     nb_places += 1
                     if gids == "":
                         gids = plce.gramps_id
@@ -899,7 +931,7 @@ class GeoGraphyView(OsmGps, NavigationView):
                         "The following places are similar : %(gid)s\n"
                         "Eiher you rename the places either you merge them."
                         "\n\n<b>I can't proceed your request</b>.\n") % {
-                                              'title': place.get_title(),
+                                              'title': place_title,
                                               'gid': gids}
                       )
             else:
@@ -913,9 +945,9 @@ class GeoGraphyView(OsmGps, NavigationView):
                                                  lat,
                                                  lon,
                                                  self.__edit_place,
-                                                 oldv)
+                                                 parent)
 
-    def __add_place(self, pcountry, pcounty, pstate, plat, plon):
+    def __add_place(self, parent, plat, plon):
         """
         Add a new place using longitude and latitude of location centered
         on the map
@@ -924,18 +956,17 @@ class GeoGraphyView(OsmGps, NavigationView):
         new_place = Place()
         new_place.set_latitude(str(plat))
         new_place.set_longitude(str(plon))
-        loc = new_place.get_main_location()
-        loc.set_country(pcountry)
-        loc.set_county(pcounty)
-        loc.set_state(pstate)
-        new_place.set_main_location(loc)
+        if parent:
+            placeref = PlaceRef()
+            placeref.ref = parent
+            new_place.add_placeref(placeref)
         try:
             EditPlace(self.dbstate, self.uistate, [], new_place)
             self.add_marker(None, None, plat, plon, None, True, 0)
         except WindowActiveError:
             pass
 
-    def __edit_place(self, pcountry, pcounty, pstate, plat, plon):
+    def __edit_place(self, parent, plat, plon):
         """
         Edit the selected place at the marker position
         """
@@ -943,17 +974,16 @@ class GeoGraphyView(OsmGps, NavigationView):
         place = self.dbstate.db.get_place_from_gramps_id(self.mark[9])
         place.set_latitude(str(plat))
         place.set_longitude(str(plon))
-        loc = place.get_main_location()
-        loc.set_country(pcountry)
-        loc.set_county(pcounty)
-        loc.set_state(pstate)
-        place.set_main_location(loc)
+        if parent:
+            placeref = PlaceRef()
+            placeref.ref = parent
+            place.add_placeref(placeref)
         try:
             EditPlace(self.dbstate, self.uistate, [], place)
         except WindowActiveError:
             pass
 
-    def __link_place(self, pcountry, pcounty, pstate, plat, plon):
+    def __link_place(self, parent, plat, plon):
         """
         Link an existing place using longitude and latitude of location centered
         on the map
@@ -964,11 +994,10 @@ class GeoGraphyView(OsmGps, NavigationView):
             self.select_fct.close()
             place.set_latitude(str(plat))
             place.set_longitude(str(plon))
-            loc = place.get_main_location()
-            loc.set_country(pcountry)
-            loc.set_county(pcounty)
-            loc.set_state(pstate)
-            place.set_main_location(loc)
+            if parent:
+                placeref = PlaceRef()
+                placeref.ref = parent
+                place.add_placeref(placeref)
             try:
                 EditPlace(self.dbstate, self.uistate, [], place)
                 self.add_marker(None, None, plat, plon, None, True, 0)
@@ -1014,7 +1043,7 @@ class GeoGraphyView(OsmGps, NavigationView):
         Add specific entry to the preference menu.
         Must be done in the associated view.
         """
-        table = Gtk.Table(2, 2)
+        table = Gtk.Table(n_rows=2, n_columns=2)
         table.set_border_width(12)
         table.set_col_spacings(6)
         table.set_row_spacings(6)
@@ -1031,15 +1060,15 @@ class GeoGraphyView(OsmGps, NavigationView):
                          config.get('geography.zoom_when_center'))
         self._config.set('geography.max_places',
                          self._config.get('geography.max_places'))
-        table = Gtk.Table(1, 1)
+        table = Gtk.Table(n_rows=1, n_columns=1)
         table.set_border_width(12)
         table.set_col_spacings(6)
         table.set_row_spacings(6)
-        configdialog.add_text(table,
+        self.path_entry = Gtk.Entry()
+        configdialog.add_path_box(table,
                 _('Where to save the tiles for offline mode.'),
-                0, line_wrap=False)
-        configdialog.add_entry(table, '',
-                1, 'geography.path')
+                0, self.path_entry, config.get('geography.path'),
+                self.set_tilepath, self.select_tilepath)
         configdialog.add_text(table,
                 _('If you have no more space in your file system. '
                   'You can remove all tiles placed in the above path.\n'
@@ -1053,10 +1082,38 @@ class GeoGraphyView(OsmGps, NavigationView):
                 _('The maximum number of places to show'),
                 4, 'geography.max_places',
                 (1000, 10000))
-        # there is no button. I need to found a solution for this.
-        # it can be very dangerous ! if someone put / in geography.path ...
-        # perhaps we need some contrôl on this path :
-        # should begin with : /home, /opt, /map, ...
-        #configdialog.add_button(table, '', 4, 'geography.clean')
+        configdialog.add_checkbox(table, 
+                _('Use keypad for shortcuts :\n' 
+                  'Either we choose the + and - from the keypad if we select this,\n'
+                  'or we use the characters from the keyboard.'),
+                5, 'geography.use-keypad',
+                extra_callback=self.update_shortcuts)
 
         return _('The map'), table
+
+    def set_tilepath(self, *obj):
+        if self.path_entry.get_text().strip():
+            config.set('geography.path', self.path_entry.get_text())
+        else:
+            config.set('geography.path', GEOGRAPHY_PATH )
+
+    def select_tilepath(self, *obj):
+        f = Gtk.FileChooserDialog(
+            _("Select tile cache directory for offline mode"),
+            action=Gtk.FileChooserAction.SELECT_FOLDER,
+            buttons=(Gtk.STOCK_CANCEL,
+                     Gtk.ResponseType.CANCEL,
+                     Gtk.STOCK_APPLY,
+                     Gtk.ResponseType.OK))
+        mpath = config.get('geography.path')
+        if not mpath:
+            mpath = HOME_DIR
+        f.set_current_folder(os.path.dirname(mpath))
+
+        status = f.run()
+        if status == Gtk.ResponseType.OK:
+            val = conv_to_unicode(f.get_filename())
+            if val:
+                self.path_entry.set_text(val)
+        f.destroy()
+
