@@ -15,11 +15,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# $Id$
-
 """
 Citation Tree View (or Source tree view).
 A view showing all the Sources with child Citations
@@ -85,10 +83,11 @@ class CitationTreeView(ListView):
     COL_DATE           =  2
     COL_CONFIDENCE     =  3
     COL_PRIV           =  4    
-    COL_CHAN           =  5    
-    COL_SRC_AUTH       =  6
-    COL_SRC_ABBR       =  7
-    COL_SRC_PINFO      =  8
+    COL_TAGS           =  5    
+    COL_CHAN           =  6    
+    COL_SRC_AUTH       =  7
+    COL_SRC_ABBR       =  8
+    COL_SRC_PINFO      =  9
     # column definitions
     COLUMNS = [
         (_('Source: Title or Citation: Volume/Page'), TEXT, None),
@@ -96,6 +95,7 @@ class CitationTreeView(ListView):
         (_('Date'), MARKUP, None),
         (_('Confidence'), TEXT, None),
         (_('Private'), ICON, 'gramps-lock'),
+        (_('Tags'), TEXT, None),
         (_('Last Changed'), TEXT, None),
         (_('Source: Author'), TEXT, None),
         (_('Source: Abbreviation'), TEXT, None),
@@ -114,9 +114,9 @@ class CitationTreeView(ListView):
         ('columns.visible', [COL_TITLE_PAGE, COL_ID, COL_SRC_AUTH,
                              COL_SRC_PINFO]),
         ('columns.rank', [COL_TITLE_PAGE, COL_ID, COL_DATE, COL_CONFIDENCE,
-                          COL_PRIV, COL_CHAN, COL_SRC_AUTH,
+                          COL_PRIV, COL_TAGS, COL_CHAN, COL_SRC_AUTH,
                           COL_SRC_ABBR, COL_SRC_PINFO]),
-        ('columns.size', [200, 75, 100, 75, 40, 100, 150, 100, 150])
+        ('columns.size', [200, 75, 100, 75, 40, 100, 100, 150, 100, 150])
         )    
     ADD_MSG = _("Add a new citation and a new source")
     ADD_SOURCE_MSG = _("Add a new source")
@@ -282,8 +282,8 @@ class CitationTreeView(ListView):
                          tip=self.ADD_CITATION_MSG, 
                          callback=self.share)
         
-        self.all_action = Gtk.ActionGroup(self.title + "/CitationAll")
-        self.edit_action = Gtk.ActionGroup(self.title + "/CitationEdit")
+        self.all_action = Gtk.ActionGroup(name=self.title + "/CitationAll")
+        self.edit_action = Gtk.ActionGroup(name=self.title + "/CitationEdit")
 
         self._add_action('FilterEdit', None, _('Citation Filter Editor'),
                          callback=self.filter_editor,)
@@ -556,6 +556,31 @@ class CitationTreeView(ListView):
         else:
             return None
 
+    def tag_updated(self, handle_list):
+        """
+        Update tagged rows when a tag color changes.
+        """
+        all_links = set([])
+        for tag_handle in handle_list:
+            links = set([link[1] for link in
+                         self.dbstate.db.find_backlink_handles(tag_handle,
+                                                include_classes='Citation')])
+            all_links = all_links.union(links)
+        self.row_update(list(all_links))
+
+    def add_tag(self, transaction, handle, tag_handle):
+        """
+        Add the given tag to the given source or citation.
+        """
+        citation = self.dbstate.db.get_citation_from_handle(handle)
+        if citation:
+            citation.add_tag(tag_handle)
+            self.dbstate.db.commit_citation(citation, transaction)
+        else:
+            source = self.dbstate.db.get_source_from_handle(handle)
+            source.add_tag(tag_handle)
+            self.dbstate.db.commit_source(source, transaction)
+
     def get_default_gramplets(self):
         """
         Define the default gramplets for the sidebar and bottombar.
