@@ -17,11 +17,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# $Id$
-
 """
 Geography for two families
 """
@@ -53,6 +51,7 @@ from gramps.gen.lib import EventRoleType, EventType
 from gramps.gen.config import config
 from gramps.gen.datehandler import displayer
 from gramps.gen.display.name import displayer as _nd
+from gramps.gen.display.place import displayer as _pd
 from gramps.gen.utils.place import conv_lat_lon
 from gramps.gui.views.navigationview import NavigationView
 from gramps.gui.views.bookmarks import FamilyBookmarks
@@ -122,6 +121,7 @@ class GeoFamClose(GeoGraphyView):
         ('geography.lock', False),
         ('geography.center-lat', 0.0),
         ('geography.center-lon', 0.0),
+        ('geography.use-keypad', True),
 
         ('geography.map_service', constants.OPENSTREETMAP),
         ('geography.max_places', 5000),
@@ -248,11 +248,11 @@ class GeoFamClose(GeoGraphyView):
         if self.reffamily:
             color = self._config.get('geography.color1')
             self._createmap(self.reffamily, color, self.place_list_ref, True)
-            self.message_layer.add_message(_("Family reference : %s") % self.family_label(self.reffamily))
+            self.message_layer.add_message(_("Family reference : %s" % self.family_label(self.reffamily)))
             if f1:
-                self.message_layer.add_message(_("The other family : %s") % self.family_label(f1))
+                self.message_layer.add_message(_("The other family : %s" % self.family_label(f1)))
             else:
-                self.message_layer.add_message(_("The other family : %s") % _("Unknown"))
+                self.message_layer.add_message(_("The other family : %s" % _("Unknown")))
             if self.reffamily_bookmark is None:
                 self.reffamily_bookmark = self.reffamily.get_handle()
                 self.add_bookmark(None, self.reffamily_bookmark)
@@ -452,7 +452,7 @@ class GeoFamClose(GeoGraphyView):
                         latitude = place.get_latitude()
                         latitude, longitude = conv_lat_lon(latitude,
                                                            longitude, "D.D8")
-                        descr = place.get_title()
+                        descr = _pd.display(dbstate.db, place)
                         evt = EventType(event.get_type())
                         descr1 = _("%(eventtype)s : %(name)s") % {
                                         'eventtype': evt,
@@ -504,7 +504,7 @@ class GeoFamClose(GeoGraphyView):
                                         latitude = place.get_latitude()
                                         latitude, longitude = conv_lat_lon(
                                                   latitude, longitude, "D.D8")
-                                        descr = place.get_title()
+                                        descr = _pd.display(dbstate.db, place)
                                         evt = EventType(
                                                   event.get_type())
                                         eyear = str("%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
@@ -709,7 +709,7 @@ class GeoFamClose(GeoGraphyView):
         Add specific entry to the preference menu.
         Must be done in the associated view.
         """
-        table = Gtk.Table(2, 2)
+        table = Gtk.Table(n_rows=2, n_columns=2)
         table.set_border_width(12)
         table.set_col_spacings(6)
         table.set_row_spacings(6)
