@@ -55,6 +55,7 @@ from gramps.gen.lib import EventRoleType, EventType
 from gramps.gen.config import config
 from gramps.gen.datehandler import displayer
 from gramps.gen.display.name import displayer as _nd
+from gramps.gen.display.place import displayer as _pd
 from gramps.gen.utils.place import conv_lat_lon
 from gramps.gui.views.pageview import PageView
 from gramps.gui.editors import EditPlace
@@ -205,7 +206,7 @@ class GeoFamily(GeoGraphyView):
                         latitude = place.get_latitude()
                         latitude, longitude = conv_lat_lon(latitude,
                                                            longitude, "D.D8")
-                        descr = place.get_title()
+                        descr = _pd.display(dbstate.db, place)
                         evt = EventType(event.get_type())
                         descr1 = _("%(eventtype)s : %(name)s") % {
                                         'eventtype': evt,
@@ -246,7 +247,7 @@ class GeoFamily(GeoGraphyView):
                                         latitude = place.get_latitude()
                                         latitude, longitude = conv_lat_lon(latitude,
                                                                            longitude, "D.D8")
-                                        descr = place.get_title()
+                                        descr = _pd.display(dbstate.db, place)
                                         evt = EventType(event.get_type())
                                         (father_name, mother_name) = self._get_father_and_mother_name(event)
                                         descr1 = "%s : %s - " % ( evt, father_name )
