@@ -56,6 +56,7 @@ from gramps.gen.lib import EventRoleType, EventType
 from gramps.gen.config import config
 from gramps.gen.datehandler import displayer
 from gramps.gen.display.name import displayer as _nd
+from gramps.gen.display.place import displayer as _pd
 from gramps.gen.utils.place import conv_lat_lon
 from gramps.gui.views.navigationview import NavigationView
 from gramps.gui.views.bookmarks import PersonBookmarks
@@ -124,6 +125,7 @@ class GeoMoves(GeoGraphyView):
         ('geography.lock', True),
         ('geography.center-lat', 0.0),
         ('geography.center-lon', 0.0),
+        ('geography.use-keypad', True),
 
         ('geography.map_service', constants.OPENSTREETMAP),
         ('geography.max_places', 5000),
@@ -286,7 +288,7 @@ class GeoMoves(GeoGraphyView):
                         latitude = place.get_latitude()
                         latitude, longitude = conv_lat_lon(latitude,
                                                            longitude, "D.D8")
-                        descr = place.get_title()
+                        descr = _pd.display(dbstate.db, place)
                         evt = EventType(event.get_type())
                         descr1 = _("%(eventtype)s : %(name)s") % {
                                         'eventtype': evt,
@@ -338,7 +340,7 @@ class GeoMoves(GeoGraphyView):
                                         latitude = place.get_latitude()
                                         latitude, longitude = conv_lat_lon(
                                                   latitude, longitude, "D.D8")
-                                        descr = place.get_title()
+                                        descr = _pd.display(dbstate.db, place)
                                         evt = EventType(
                                                   event.get_type())
                                         eyear = str("%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
