@@ -57,6 +57,7 @@ from gramps.gen.lib import EventRoleType, EventType
 from gramps.gen.config import config
 from gramps.gen.datehandler import displayer
 from gramps.gen.display.name import displayer as _nd
+from gramps.gen.display.place import displayer as _pd
 from gramps.gen.utils.place import conv_lat_lon
 from gramps.gui.views.pageview import PageView
 from gramps.gui.editors import EditPlace
@@ -128,6 +129,7 @@ class GeoPerson(GeoGraphyView):
         ('geography.lock', False),
         ('geography.center-lat', 0.0),
         ('geography.center-lon', 0.0),
+        ('geography.use-keypad', True),
 
         #('geography.gps_mode', GPS_DISABLED),
         #('geography.gps_update_rate', float(1.0)),
@@ -321,7 +323,7 @@ class GeoPerson(GeoGraphyView):
                         latitude = place.get_latitude()
                         latitude, longitude = conv_lat_lon(latitude,
                                                            longitude, "D.D8")
-                        descr = place.get_title()
+                        descr = _pd.display(dbstate.db, place)
                         evt = EventType(event.get_type())
                         descr1 = _("%(eventtype)s : %(name)s") % {
                                         'eventtype': evt,
@@ -371,7 +373,7 @@ class GeoPerson(GeoGraphyView):
                                         latitude = place.get_latitude()
                                         latitude, longitude = conv_lat_lon(latitude,
                                                                            longitude, "D.D8")
-                                        descr = place.get_title()
+                                        descr = _pd.display(dbstate.db, place)
                                         evt = EventType(event.get_type())
                                         eyear = str("%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
                                                   str("%02d" % event.get_date_object().to_calendar(self.cal).get_month()) + \
